%define ALD_Ver		1.2.1

%define BUILD_python 0

Name:         libxml2

License:      MIT
Summary:      Library providing XML and HTML support
Group:        Development/Libraries
Version:      2.7.8
Release:      1
URL: http://xmlsoft.org/

Source: %{name}-%{version}.tar.xz
Source1: CROSS.sh

%define DestDir		%{nil}
# -----------------------------------------------------
%if %{_target_cpu} == %{_build_cpu}
%define _CROSS 0
%define BUILD_LOCAL_CROSS 0
%else
# rpm --target=x86_64/armv6l/win32 -ba xxxxx.spec
%define _CROSS 1
%define BUILD_LOCAL_CROSS 1
%endif

%define TO_ARCH %{_target_cpu}

%if %{_target_cpu} == "armv6l"
%define ARM_ARCH armv6zk
%define ARM_FPU  -mfpu=vfp -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%if %{_target_cpu} == "armv7l"
%define ARM_ARCH armv7-a
%define ARM_FPU  -mfpu=vfpv3-d16 -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%define BUILD_TAR 1
#------------------ CROSS DIR --------------------
%if %{_CROSS}

%if %{_os} == "mingw"
%define target %{_arch}-%{_vendor}-%{_os}%{__isa_bits}
%else  #win32 || win64
%define target %{_arch}-%{_os}%{_gnu}
%endif
%define target_  %{target}-

%define crossdir	/cross
%if %{_arch} == "arm"
%define csysdir		%{crossdir}/%{ARM_ARCH}
%else
%define csysdir		%{crossdir}/%{_target_cpu}
%endif
%define csysbindir	%{csysdir}/bin

%define __os_install_post %{nil}

%define cross_bindir	%{csysdir}%{_bindir}
%define cross_libdir	%{csysdir}%{_libdir}
%define cross_includedir %{csysdir}%{_includedir}
%define cross_datadir	%{csysdir}%{_datadir}
%define cross_infodir	%{csysdir}%{_infodir}
%define cross_mandir	%{csysdir}%{_mandir}
%define cross_defaultdocdir %{csysdir}%{_defaultdocdir}
%define cross_docdir	%{cross_defaultdocdir}/%{name}

%define CrossDestDir	/Cross

%define _srcrpmdir	%{_topdir}/SRPMS/tmp

%else  #_CROSS

%define csysbindir	%{_prefix}/bin
%define CrossDestDir	%{nil}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}

%define target_  %{nil}
%define target %{_build}

%endif # !_CROSS

%define docdir %{_defaultdocdir}/%{name}

# ------------------- description ------------------------------------
%description
This library allows to manipulate XML files. It includes support 
to read, modify and write XML and HTML files. There is DTDs support
this includes parsing and validation even with complex DtDs, either
at parse time or later once the document has been modified. The output
can be a simple SAX stream or and in-memory DOM like representations.
In this case one can use the built-in XPath and XPointer implementation
to select subnodes or ranges. A flexible Input/Output mechanism is
available, with existing HTTP and FTP modules and combined to an
URI library.
#-------------------------------
%package devel
Summary:      Libraries for the C compiler
Group:        Development/Libraries
%description devel
These libraries are needed to compile C code.
#-------------------------------

%if %BUILD_python
%package python
Summary: Python bindings for the libxml2 library
Group: Development/Libraries
Requires: libxml2 = %{version}

%description python
The libxml2-python package contains a module that permits applications
written in the Python programming language to use the interface
supplied by the libxml2 library to manipulate XML files.
%endif
#-------------------------------
%package doc
Summary:      doc for %{name}
Group:        Documentation
%description doc
doc for %{name}
#-------------------------------
%package %{TO_ARCH}
Summary:      %{name} Cross-%{TO_ARCH} Libraries
Group:        Development/Libraries
%description %{TO_ARCH}
%{name} Cross-%{TO_ARCH} Libraries

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{name}-%{version}

# ------------------- Build ------------------------------------------
%Build 
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

%if %{_arch} == "i386"
OPTFLAGS="-O2 -march=i486 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-O2 -fno-asynchronous-unwind-tables"
%endif
%if %{_arch} == "arm"
OPTFLAGS="-O2 -march=%{ARM_ARCH} %{ARM_FPU} -munaligned-access"
%endif

%if %{_os} == "mingw"
CFLAGS="$OPTFLAGS -std=gnu99"
LDFLAGS=" "
%else
CFLAGS="$OPTFLAGS -ffunction-sections -fdata-sections -std=gnu99"
GCC_VER_STR=`%{target_}gcc -dumpversion`
LDFLAGS=`case $GCC_VER_STR in \
 4.[56789].*) echo -static-libgcc ;; \
 esac`
LDFLAGS="$LDFLAGS -Wl,--gc-sections"
%endif

%configure \
	--build=%{_build} \
%if %{_CROSS}
	--host=%{target} \
%endif
%if %{_os} == "mingw"
	--disable-shared \
%else
	--enable-shared \
%endif
	--with-html-dir=%{_defaultdocdir} \
	--with-debug \
	--enable-ipv6=no \
	--disable-static \
	--disable-libtool-lock \
	--without-python \
	&>FConfigure_log.txt

make &>FMake_log.txt

# ------------------- Install ----------------------------------------
%Install
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
#mkdir -p $RPM_BUILD_ROOT%{docdir}

make DESTDIR=$RPM_BUILD_ROOT install &>FInstall_log.txt
rm $RPM_BUILD_ROOT%{_libdir}/*.la
cp AUTHORS README $RPM_BUILD_ROOT%{_defaultdocdir}/%{name}-%{version}/

%if %{_CROSS}
TARGET_PRFIX=%{_prefix}
TARGET_CROSS_PRFIX=%{csysdir}
TARGET_NAME=%{target}
MKCROSSDIR=%{BUILD_LOCAL_CROSS}
export TARGET_PRFIX TARGET_CROSS_PRFIX TARGET_NAME MKCROSSDIR
%SOURCE1
%if %{BUILD_LOCAL_CROSS}
rm -r $RPM_BUILD_ROOT%{cross_bindir}/xmlcatalog
rm -r $RPM_BUILD_ROOT%{cross_bindir}/xmllint
mv $RPM_BUILD_ROOT%{cross_bindir} $RPM_BUILD_ROOT%{csysbindir}

pushd $RPM_BUILD_ROOT%{csysbindir}
sed -i s:"/usr":"%{csysdir}/usr": xml2-config
#chmod 0744 xml2-config
popd

rm -r $RPM_BUILD_ROOT%{cross_defaultdocdir}/%{name}-%{version}/examples
rm -r $RPM_BUILD_ROOT%{cross_defaultdocdir}/%{name}-%{version}/html
rm -r $RPM_BUILD_ROOT%{cross_datadir}/gtk-doc
rm -r $RPM_BUILD_ROOT%{cross_mandir}

pushd $RPM_BUILD_ROOT%{cross_libdir}
sed -i s:"-L/usr/lib":"-L%{cross_libdir}": xml2Conf.sh
sed -i s:"-I/usr/include":"-I%{cross_includedir}": xml2Conf.sh
popd
%endif #BUILD_LOCAL_CROSS
%endif #_CROSS


mkdir -p $RPM_BUILD_ROOT/usr
mkdir -p $RPM_BUILD_ROOT/etc/sgml
mkdir -p $RPM_BUILD_ROOT/etc/xml

mv $RPM_BUILD_ROOT%{_datadir}/gtk-doc/html/libxml2 $RPM_BUILD_ROOT%{_defaultdocdir}/%{name}-%{version}/libxml2
rm -r $RPM_BUILD_ROOT%{_datadir}/gtk-doc

mkdir -p $RPM_BUILD_ROOT%{_defaultdocdir}/%{name}-%{version}/devel
cp doc/*.html $RPM_BUILD_ROOT%{_defaultdocdir}/%{name}-%{version}/devel
cp doc/*.gif $RPM_BUILD_ROOT%{_defaultdocdir}/%{name}-%{version}/devel
cp doc/*.png $RPM_BUILD_ROOT%{_defaultdocdir}/%{name}-%{version}/devel

%if %BUILD_python
mkdir -p $RPM_BUILD_ROOT%{_defaultdocdir}/%{name}-%{version}/python/tests
cp python/libxml2class.txt $RPM_BUILD_ROOT%{_defaultdocdir}/%{name}-%{version}/python
cp python/*.py $RPM_BUILD_ROOT%{_defaultdocdir}/%{name}-%{version}/python
cp python/python.html $RPM_BUILD_ROOT%{_defaultdocdir}/%{name}-%{version}/python
cp python/tests/*.py $RPM_BUILD_ROOT%{_defaultdocdir}/%{name}-%{version}/python/tests
%endif

# ------------------- Clean ------------------------------------------
%Clean 
DE=%{version}-%{release}.%{TO_ARCH}.rpm
DD=%{_rpmdir}/%{TO_ARCH}/%{ALD_Ver}%{DestDir}
DEC=%{version}-%{release}.%{_build_cpu}.rpm
DDC=%{_rpmdir}/%{_build_cpu}/%{ALD_Ver}%{CrossDestDir}/%{TO_ARCH}%{DestDir}

pushd %{_rpmdir}/%{_target_cpu}
  SE=%{version}-%{release}.%{_target_cpu}.rpm
  mkdir -p $DD
  mv %{name}-$SE $DD/%{name}-$DE
  mv %{name}-devel-$SE $DD/%{name}-devel-$DE
  mv %{name}-doc-$SE $DD/%{name}-doc-$DE
%if %{BUILD_LOCAL_CROSS}
  mkdir -p $DDC
  mv %{name}-%{TO_ARCH}-$SE $DDC/%{name}-%{TO_ARCH}-$DEC
%endif #BUILD_LOCAL_CROSS
popd

# --------------- build *.tgz ------------------------
%if %{BUILD_TAR}
pushd $RPM_BUILD_ROOT
  TMP_TO=$DD/tar
  mkdir -p $TMP_TO
  tmp=%{name}-%{version}-%{release}.%{TO_ARCH}
  mkdir -p $tmp
  cp -r etc usr $tmp/
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
  rm -r $tmp
%if %{BUILD_LOCAL_CROSS}
  TMP_TO=$DDC/tar
  mkdir -p $TMP_TO
  tmp=%{name}-%{TO_ARCH}-%{version}-%{release}.%{_build_cpu}
  mkdir -p $tmp
  cp -r cross $tmp/
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
  rm -r $tmp
%endif
popd
%endif  #BUILD_TAR

%post
if test ! -e /etc/xml/catalog; then
  xmlcatalog -v --create --noout /etc/xml/catalog
fi

# ------------------- Files ------------------------------------------
%if %{_os} == "mingw"
%Files
%{_prefix}

%if %{BUILD_LOCAL_CROSS}
%Files %{TO_ARCH}
%{csysdir}
%endif #!BUILD_LOCAL_CROSS
%else  #mingw

%Files
/etc
%{_bindir}/xmllint
%{_bindir}/xmlcatalog
%{_libdir}/*.so.*
%{_mandir}/man1
%{_mandir}/man3
%{docdir}-%{version}/Copyright
%{docdir}-%{version}/AUTHORS
%{docdir}-%{version}/README

%files devel
%{_bindir}/xml2-config
%{_includedir}
%{_libdir}/*.so
%{_libdir}/*.sh
%{_libdir}/pkgconfig
%{_datadir}/aclocal

%if %BUILD_python
%files python
%{_libdir}/python*
%{docdir}-%{version}/python
%endif

%files doc
%{docdir}-%{version}/devel
%{docdir}-%{version}/examples
%{docdir}-%{version}/html
%{docdir}-%{version}/libxml2

# ------------------- Cross Files ------------------------------------
%if %{BUILD_LOCAL_CROSS}

%Files %{TO_ARCH}
%{csysbindir}
%{cross_libdir}
%{cross_includedir}
%{cross_datadir}/aclocal
%{cross_defaultdocdir}

%endif #!BUILD_LOCAL_CROSS
%endif #!mingw
